[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- object: The most base type
  - exceptions.BaseException: Common base class for all exceptions
    - exceptions.Exception: Common base class for all non-exit exceptions.
      - EasyExtend.util.hexobject.NotConvertibleException
      - EasyExtend.langlets.p4d.langlet.SpecialElement
      - exceptions.StandardError: Base class for all standard Python exceptions that do not represent interpreter exiting.
        - exceptions.AttributeError: Attribute not found.
          - EasyExtend.langlets.p4d.p4dbase.P4DAccessError
      - exceptions.Warning: Base class for warning categories.
        - EasyExtend.langlets.p4d.p4dutils.TagIsKeywordWarning
  - EasyExtend.langlets.p4d.xmlutils.BeautifulSoupParser
  - EasyExtend.eeoptions.EEShow: EEShow is an abstract base class.
    - EasyExtend.eetokenizer.BaseTokenizer: Abstract base class of Tokenizer classes.
      - EasyExtend.eetokenizer.Tokenizer
        - EasyExtend.langlets.p4d.langlet.LangletTokenizer: Defines langlet specific token stream processor.
  - EasyExtend.util.Enum.Enum
    - EasyExtend.util.hexobject.PAD_MODE
  - EasyExtend.langlets.p4d.p4dbase.FileLike
  - EasyExtend.langlets.p4d.bytelet.Flow
    - EasyExtend.langlets.p4d.bytelet.FlowFieldVal
    - EasyExtend.langlets.p4d.bytelet.FlowLen
      - EasyExtend.langlets.p4d.bytelet.FlowLenBER
      - EasyExtend.langlets.p4d.bytelet.FlowLenRaw
  - EasyExtend.util.hexobject.HexOrBin
    - EasyExtend.util.hexobject.Hex: Generic hexadecimal object.
  - EasyExtend.eeimporter.Importer
    - EasyExtend.langlets.p4d.langlet.LangletImporter: Defines langlet specific import behaviour.
  - EasyExtend.langlets.p4d.p4dbase.P4D: P4D objects are lazy wrappers around nested lists that store XML or P4D data.
    - EasyExtend.langlets.p4d.bytelet.Bytelet: Bytelets are flexible data structures used for binary serialization.
      - EasyExtend.langlets.p4d.bytelet.ByteletSchema
  - EasyExtend.langlets.p4d.p4dbase.P4DNamespace
  - EasyExtend.langlets.p4d.p4dbase.P4DNode: Used to build list-trees from the bottom up.
  - EasyExtend.langlets.p4d.xmlutils.Parser
    - EasyExtend.langlets.p4d.xmlutils.ExpatParser
  - EasyExtend.eetransformer.Transformer
    - EasyExtend.langlets.p4d.langlet.LangletTransformer: Defines langlet specific CST transformations.
      - EasyExtend.langlets.p4d.langlet.InteractiveTransformer
  - EasyExtend.langlets.p4d.p4dbase._child_iter
  - basestring: Type basestring cannot be instantiated; it is the base for str and unicode.
    - str: str(object) -> string
      - EasyExtend.langlets.p4d.p4dbase.P4DName
  - dict: dict() -> new empty dictionary.
    - EasyExtend.langlets.p4d.p4dbase.P4DAttributes
  - int: int(x[, base]) -> integer
    - EasyExtend.util.hexobject.Bin
  - list: list() -> new list list(sequence) -> new list initialized from sequence's items
    - EasyExtend.util.hexobject.Bits
    - EasyExtend.langlets.p4d.p4dbase.P4DContentList
    - EasyExtend.langlets.p4d.p4dbase.P4DList: Class used to represent lists of P4D objects.
      - EasyExtend.langlets.p4d.bytelet.ByteletList: Class used to represent lists of P4D objects.
  - EasyExtend.langlets.p4d.p4dutils.pprinter
    - EasyExtend.langlets.p4d.p4dutils.p4dprinter
    - EasyExtend.langlets.p4d.xmlutils.xmlprinter
  - type: type(object) -> the object's type type(name, bases, dict) -> a new type
    - EasyExtend.util.Enum.EnumMetaclass: Metaclass for enumeration.